function ents=enth3(ti,tf,s,j)
% enth3 finds the sensible enthalpy change (J/mol)for compounds
%      designated in the vector j or all of them if 4th argument
%      is omitted.
% All the designated cmpds MUST be in the same state and
%      must be set with start301 before execution of enth3 
%  
% function ents=enth3(ti,tf,s,j)
% Arguments:
%      ti    the initial temperature in K.
%      tf    the final temperature in K.
%      s     the state of the compounds: 
%   	       'v'    for vapor or 
%		       'l'    for liquid or 
%            's'    for solid.
%      j     compounds designated in cnms
% See also ENTH1 and ENTH2
%
% Example:  After executing start301. 
%   with the compounds: benzene(1), water(2), carbon(3)
% >>enth3(300,400,'v',1:2)
%
% OKB, revised help by TYLC, SHD, & MAH
global nc
if nargin==3
   j=1:nc;
end
for i=j
   ents(i)=enth2(ti,tf,intcp2(s,i));
end
